This functions plots a microbial growth curve with the option to add a confidence interval. Under the hood, it is a simple ggplot2 wrapper, with defaults set depending on the type of plot. As such, it can be expanded upon using the usual ggplot2 syntax.

plotGrowthCurve(data, x, y, grouping, color, type = "robert")

Arguments

data

A data frame containing the data to plot.

x

The x-axis variable. Usually the time in hours after starting the experiment.

y

The y-axis variable. Usually the concentration of microbes per mL as a double

grouping

A character vector containing one or more column names for the grouping variables. Usually "c("timepoint", "organism")".

color

The color variable. Usually the strain or condition.

type

The type of plot to create. Currently only 'robert' is supported. This sets the default look for the plot.

See also

The first steps chapter of the online ggplot2 book.

Examples

if (FALSE) { # \dontrun{
# load example data from this package
growthData <- archaeacentre::growthData
# plot the growth curve
plotGrowthCurve(growthData, timepoint, concentration, grouping = c("timepoint", "organism"), organism, type = "robert")
} # }